@@ -13,7 +13,8 @@ from roadwork.json import Unserializer
 
 import uuid
 
-#asgiref
+import logging
+logger = logging.getLogger('RW-Client')
 
 class ClientDapr:
     metadata = { 'render.modes': [ 'human' ] }
@@ -25,7 +26,7 @@ class ClientDapr:
         self.init_roadwork_client()
 
     def init_roadwork_client(self):
-        # 'https://20.190.28.131:443'
+
         rw_server_url = os.environ.get('ROADWORK_SERVER_URL')
         if rw_server_url:
             self.client_session.headers = {'Host': 'roadwork'}
@@ -34,6 +35,7 @@ class ClientDapr:
         else:
             dapr_http_port = os.environ.get("DAPR_HTTP_PORT", "3500")
             rw_server_url = f'http://127.0.0.1:{dapr_http_port}'
+
         self._default_url = f'{rw_server_url}/v1.0/actors/{self.simId}/{self.actor_id}/method'
 
         print(f'connection - {self._default_url}')
@@ -61,16 +63,26 @@ class ClientDapr:
         if isinstance(action, np.ndarray):
             action = action.tolist()
 
-        for _ in range(0, 3):
+        for _ in range(0, 5):
             try:
                 r = self.client_session.post(f'{self._default_url}/SimStep', json={ 'action': action })
-                if len(r.json()) == 0:
-                    return []
-                obs, reward, done, info = r.json()
+                if not r.ok:
+                    logger.warn(f'error response - status_code : {r.status_code} - {r.reason}')
+                    continue
+
+                r_json = r.json()
+
+                if len(r_json) < 4:
+                    logger.warn(f'error response - less arguments: {r.text}')
+                    continue
+
+                obs, reward, done, info = r_json
                 return [ obs, reward, done, info ]
             except Exception as ex:
-                print (repr(ex), flush=True)
-                time.sleep(1)
+                logger.exception(ex)
+
+            time.sleep(0.5)
+      
         return []
 
     def _monitor_start(self, episode_interval):
